<template>
    <div class="table">
        <div class="table_content">
<!--            <div></div>-->
            <el-table
                v-loading="listLoading"
                :key="tableKey"
                :data="checkData"
                border
                fit
                id="areaSheet"
                highlight-current-row
                style="width: 100%;"
            >

                <el-table-column type="index" label="序号" align="center" width="80"/>
                <el-table-column label="单位名称" prop="enterpriseName" align="center" width="180"></el-table-column>
                <el-table-column label="联系电话" prop="enterpriseOfficephone" align="center"></el-table-column>
                <el-table-column label="库存数量/万箱" prop="stockNum" align="center"></el-table-column>
                <el-table-column label="库容量/万箱" prop="storageCapacity" align="center"></el-table-column>
                <el-table-column label="是否查出隐患" prop="hiddendangerStatus" align="center">
                    <template slot-scope="scope">
                        <span>{{ scope.row.hiddendangerStatus == 1 ? '是' : '否' }}</span>
                    </template>
                </el-table-column>
                <el-table-column label="是否自查" prop="selfcheckStatus" align="center">
                    <template slot-scope="scope">
                        <span>{{ scope.row.selfcheckStatus == 1 ? '已自查' : '未自查' }}</span>
                    </template>
                </el-table-column>
                <el-table-column label="被检查次数" prop="checkedTimes" align="center"></el-table-column>
                <el-table-column label="隐患数量" prop="hiddendangerSum" align="center"></el-table-column>
                <el-table-column label="整改数量" prop="rectifyHiddendangerSum" align="center"></el-table-column>
                <el-table-column label="重大整改数量" prop="rectifyMajorHiddendangerNum" align="center"></el-table-column>
                <el-table-column fixed="right" label="操作" align="center" class-name="small-padding fixed-width">
                    <template slot-scope="scope">
                        <el-button type="text" @click="toEnterprises(scope.row.selfAndcheckInfos)">查看</el-button>
                    </template>
                </el-table-column>
            </el-table>

            <el-pagination
                v-show="recordTotal>0"
                :current-page="currentPage"
                :page-sizes="[10, 15]"
                :page-size="pageSize"
                :total="recordTotal"
                layout="total, sizes, prev, pager, next, jumper"
                background
                style="float:right;margin:3px"
                @size-change="handleSizeChange"
                @current-change="handleCurrentChange"
            />
        </div>
        <area-enterprises ref="enterPrises"></area-enterprises>
    </div>
</template>

<script>
import {mapGetters} from "vuex";
import Cookies from "_js-cookie@2.2.0@js-cookie";
import {paramList} from "../../../api/contract";
import {computePageCount} from "../../../utils";
import {parseError} from "../../../utils/messageDialog";
import { getCheckUnitType, getEnterpriseCompleteInfoList, getDataStatistics, getSpecialCheckTask } from "@/api/specialCheck"
import AreaEnterprises from "./areaEnterprises";

export default {
name: "areaForm",
    components: {AreaEnterprises},
    data(){
        return{
            recordTotal: 0,
            pageSize: 10,
            currentPage: 1,
            unitType: null,
            taskId: null,
            enterpriseType: null,
            enterpriseCity: '',
            enterpriseArea: '',
            listLoading: false,
            tableKey: 0,
            checkData: []
        }
    },
    created() {
        const t = this
        t.getCheckUnitType()
        if(t.taskId){t.getAreaStatistics()}
    },
    computed: {
        ...mapGetters([
            'userType',
            'name'
        ])
    },
    methods:{
        async getCheckUnitType(){
            const t = this
            t.listLoading = true
            let res = await getCheckUnitType()
            if(res.data.code === "200"){
                t.unitType = res.data.result.checkUnitType
            }else{
                t.$message({
                    type:'warning',
                    message:res.data.message
                })
            }
            t.listLoading = false
        },
        async getAreaStatistics(){
            const t = this
            const data = {id: t.taskId,enterpriseType: t.enterpriseType,enterpriseCity: t.enterpriseCity,enterpriseArea: t.enterpriseArea,pageIndex: t.currentPage,pageSize: t.pageSize}
            const res = await getDataStatistics(data)
            if(res.data.code === "200"){
                t.checkData = res.data.result.records
                t.recordTotal = res.data.result.total
            }else{
                t.$message({
                    type:'warning',
                    message:res.data.message
                })
            }
        },

        handleSizeChange: function (val) {
            this.pageSize = val
            this.currentPage = 1
            this.getAreaStatistics()
        },
        handleCurrentChange: function (val) {
            this.currentPage = val
            this.getAreaStatistics()
        },

        toEnterprises(infos){
            this.$refs.enterPrises.checkList = infos
            this.$refs.enterPrises.enterpriseType = this.enterpriseType
            this.$refs.enterPrises.dialogVisible = true
        }
    }
}
</script>

<style lang="scss" scoped>
    .table{
        width: 100%;
        height: 100%;
    }
</style>
